//---------------------------------------------------------------------------
#ifndef cipherfrmH
#define cipherfrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <ExtCtrls.hpp>
#include <swbuf.h>
#include <swconfig.h>

using namespace sword;
//---------------------------------------------------------------------------
class TCipherForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TPanel *Panel3;
	TLabel *Label1;
	TLabel *Label2;
	TEdit *cipherEdit;
	TMemo *Memo1;
	TButton *Button1;
	TButton *Button2;
	TButton *Button3;
	void __fastcall Button2Click(TObject *Sender);
	void __fastcall FormShow(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
private:	// User declarations
public:		// User declarations
	SWConfig *config;
	SWBuf modName;
	__fastcall TCipherForm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern PACKAGE TCipherForm *CipherForm;
//---------------------------------------------------------------------------
#endif
